#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-prelude
version:              1.8.1
visibility:           public
id:                   clash-prelude-1.8.1-6gQDpyYTmDbBWkK5VWq0z8
key:                  clash-prelude-1.8.1-6gQDpyYTmDbBWkK5VWq0z8
license:              BSD-2-Clause
copyright:
    Copyright © 2013-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.,
    2021-2023, QBayLogic B.V.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - Prelude library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Prelude library containing datatypes and functions for circuit design

    To use the library:

    * Import "Clash.Prelude"

    * Alternatively, if you want to explicitly route clock and reset ports,
    for more straightforward multi-clock designs, you can import the
    "Clash.Explicit.Prelude" module. Note that you should not import
    "Clash.Prelude" and "Clash.Explicit.Prelude" at the same time as they
    have overlapping definitions.

    A preliminary version of a tutorial can be found in "Clash.Tutorial", for a
    general overview of the library you should however check out "Clash.Prelude".
    Some circuit examples can be found in "Clash.Examples".

category:             Hardware
abi:                  dc556a205a375280de13adb1b1757352
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation
    Clash.Annotations.BitRepresentation.Deriving
    Clash.Annotations.BitRepresentation.Internal
    Clash.Annotations.BitRepresentation.Util
    Clash.Annotations.Primitive Clash.Annotations.SynthesisAttributes
    Clash.Annotations.TH Clash.Annotations.TopEntity
    Clash.Class.AutoReg Clash.Class.AutoReg.Internal
    Clash.Class.BitPack Clash.Class.BitPack.BitIndex
    Clash.Class.BitPack.BitReduction Clash.Class.BitPack.Internal
    Clash.Class.BitPack.Internal.TH Clash.Class.Counter
    Clash.Class.Counter.Internal Clash.Class.Counter.TH Clash.Class.Exp
    Clash.Class.HasDomain Clash.Class.HasDomain.CodeGen
    Clash.Class.HasDomain.Common Clash.Class.HasDomain.HasSingleDomain
    Clash.Class.HasDomain.HasSpecificDomain Clash.Class.Num
    Clash.Class.Parity Clash.Class.Resize Clash.Clocks Clash.Examples
    Clash.Examples.Internal Clash.Explicit.BlockRam
    Clash.Explicit.BlockRam.Blob Clash.Explicit.BlockRam.File
    Clash.Explicit.BlockRam.Internal Clash.Explicit.BlockRam.Model
    Clash.Explicit.DDR Clash.Explicit.Mealy Clash.Explicit.Moore
    Clash.Explicit.Prelude Clash.Explicit.Prelude.Safe
    Clash.Explicit.RAM Clash.Explicit.ROM Clash.Explicit.ROM.Blob
    Clash.Explicit.ROM.File Clash.Explicit.Reset Clash.Explicit.Signal
    Clash.Explicit.Signal.Delayed Clash.Explicit.SimIO
    Clash.Explicit.Synchronizer Clash.Explicit.Testbench
    Clash.Explicit.Verification Clash.HaskellPrelude Clash.Hidden
    Clash.Intel.ClockGen Clash.Intel.DDR Clash.Magic Clash.NamedTypes
    Clash.Num.Erroring Clash.Num.Overflowing Clash.Num.Saturating
    Clash.Num.Wrapping Clash.Num.Zeroing Clash.Prelude
    Clash.Prelude.BlockRam Clash.Prelude.BlockRam.Blob
    Clash.Prelude.BlockRam.File Clash.Prelude.DataFlow
    Clash.Prelude.Mealy Clash.Prelude.Moore Clash.Prelude.RAM
    Clash.Prelude.ROM Clash.Prelude.ROM.Blob Clash.Prelude.ROM.File
    Clash.Prelude.Safe Clash.Prelude.Testbench Clash.Promoted.Nat
    Clash.Promoted.Nat.Literals Clash.Promoted.Nat.TH
    Clash.Promoted.Nat.Unsafe Clash.Promoted.Symbol Clash.Signal
    Clash.Signal.BiSignal Clash.Signal.Bundle Clash.Signal.Delayed
    Clash.Signal.Delayed.Bundle Clash.Signal.Delayed.Internal
    Clash.Signal.Internal Clash.Signal.Internal.Ambiguous
    Clash.Signal.Trace Clash.Sized.BitVector Clash.Sized.Fixed
    Clash.Sized.Index Clash.Sized.Internal.BitVector
    Clash.Sized.Internal.Index Clash.Sized.Internal.Mod
    Clash.Sized.Internal.Signed Clash.Sized.Internal.Unsigned
    Clash.Sized.RTree Clash.Sized.Signed Clash.Sized.Unsigned
    Clash.Sized.Vector Clash.Tutorial Clash.Verification
    Clash.Verification.DSL Clash.Verification.Internal Clash.XException
    Clash.XException.Internal Clash.XException.MaybeX
    Clash.XException.TH Clash.Xilinx.ClockGen Clash.Xilinx.DDR

hidden-modules:
    Clash.Class.AutoReg.Instances Clash.Clocks.Internal Clash.CPP
    Clash.Signal.Bundle.Internal Language.Haskell.TH.Compat
    Paths_clash_prelude

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-prelude-1.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-prelude-1.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-prelude-1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clash-prelude
hs-libraries:         HSclash-prelude-1.8.1-6gQDpyYTmDbBWkK5VWq0z8
depends:
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF array-0.5.4.0
    arrows-0.4.4.2-K1a8qZhauap5wVxM3Cu1Eo base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 constraints-0.13.4-IYZaAOOKAgpGLaWrPEXfUK
    containers-0.6.7 data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc deepseq-1.4.8.0
    extra-1.7.16-8afQiu2kMl021rKAXFYaei ghc-bignum-1.3 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.5-D2cGxzQWboDLouUDvPMZ1b
    ghc-typelits-knownnat-0.7.8-9POOw5rxN28mMVyfLt5ig
    ghc-typelits-natnormalise-0.7.9-Cwq0u8cCG1BDrdwyZ38bk3
    half-0.3.2-K5YBh2hFOfsDmjdFaG2a7Y
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    infinite-list-0.1.2-EcOYnarUZGSC7OcliAAhLS
    lens-5.2.3-KMe0UA9rcY2CQDwAzcGcMr mtl-2.2.2
    recursion-schemes-5.2.3-9iTO4XIUoHb3IPrWpzXSXJ
    reflection-2.1.9-3QryVbiH76WulDKufrvCI
    singletons-3.0.4-5pDsUnwe3c7FZQt4Yt8MEN
    string-interpolate-0.3.4.0-7yNEGJc5oNzAnAtBCQSlr6
    template-haskell-2.19.0.0 text-2.0.2
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-orphans-0.13.15-5TtNICmSa6ID7If1AS2SbY time-1.12.2
    transformers-0.5.6.2 type-errors-0.2.0.2-GqdlvdN0dGLg6a1AEru8s
    uniplate-1.6.13-8GWqyDLzdG1GIR763aHdX
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-clash-prelude/html/clash-prelude.haddock

haddock-html:         /usr/share/doc/haskell-clash-prelude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

